summaryrefslogtreecommitdiffstats
path: root/tdestyles/kthemestyle/kthemestyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tdestyles/kthemestyle/kthemestyle.cpp')
-rw-r--r--tdestyles/kthemestyle/kthemestyle.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/tdestyles/kthemestyle/kthemestyle.cpp b/tdestyles/kthemestyle/kthemestyle.cpp
index bd89fb060..2971655ff 100644
--- a/tdestyles/kthemestyle/kthemestyle.cpp
+++ b/tdestyles/kthemestyle/kthemestyle.cpp
@@ -523,10 +523,10 @@ void KThemeStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
if (ceData.widgetObjectTypes.contains("TQWidget")) {
TQWidget *w = reinterpret_cast<TQWidget*>(ptr);
- if (::tqqt_cast<TQStatusBar*>(w))
+ if (::tqt_cast<TQStatusBar*>(w))
w->setPaletteBackgroundColor(TQApplication::palette().color(TQPalette::Normal, TQColorGroup::Background));
- if (::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
+ if (::tqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
installObjectEventHandler(ceData, elementFlags, ptr, this);
if (w->backgroundPixmap() && !w->isTopLevel() &&
@@ -565,7 +565,7 @@ void KThemeStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
return ;
}
- if ( ::tqqt_cast<TQMenuBar*>(w) )
+ if ( ::tqt_cast<TQMenuBar*>(w) )
{
w->setBackgroundMode( TQWidget::NoBackground );
}
@@ -573,7 +573,7 @@ void KThemeStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
{
w->setBackgroundMode( TQWidget::PaletteBackground );
}
- else if ( ::tqqt_cast<TQPopupMenu*>(w) )
+ else if ( ::tqt_cast<TQPopupMenu*>(w) )
{
popupPalette = w->palette();
if ( isColor( MenuItem ) || isColor( MenuItemDown ) )
@@ -593,7 +593,7 @@ void KThemeStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
w->setBackgroundMode( TQWidget::NoBackground );
}
- else if ( ::tqqt_cast<TQCheckBox*>(w) )
+ else if ( ::tqt_cast<TQCheckBox*>(w) )
{
if ( isColor( IndicatorOff ) || isColor( IndicatorOn ) )
{
@@ -608,7 +608,7 @@ void KThemeStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
w->setPalette( newPal );
}
}
- else if ( ::tqqt_cast<TQRadioButton*>(w) )
+ else if ( ::tqt_cast<TQRadioButton*>(w) )
{
if ( isColor( ExIndicatorOff ) || isColor( ExIndicatorOn ) )
{
@@ -644,21 +644,21 @@ void KThemeStyle::unPolish( const TQStyleControlElementData &ceData, ControlElem
}
//Toolbar labels should nornally be PaletteButton
- if ( ::tqqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
+ if ( ::tqt_cast<TQLabel*>(w) && !qstrcmp(w->name(), "tde toolbar widget"))
w->setBackgroundMode( TQWidget::PaletteButton );
//The same for menu bars, popup menus
- else if ( ::tqqt_cast<TQMenuBar*>(w) || ::tqqt_cast<TQPopupMenu*>(w) )
+ else if ( ::tqt_cast<TQMenuBar*>(w) || ::tqt_cast<TQPopupMenu*>(w) )
w->setBackgroundMode( TQWidget::PaletteButton );
//For toolbar internal separators, return to button, too (can't use tqqt_cast here since don't have access to the class)
else if ( w->inherits( "TDEToolBarSeparator" ) || w->inherits( "QToolBarSeparator" ) )
w->setBackgroundMode( TQWidget::PaletteButton );
//For scrollbars, we don't do much, since the widget queries the style on the switch
//Drop some custom palettes. ### this really should check the serial number to be 100% correct.
- if ( ::tqqt_cast<TQPopupMenu*>(w) || ::tqqt_cast<TQCheckBox*>(w) || ::tqqt_cast<TQRadioButton*>(w) || ::tqqt_cast<TQStatusBar*>(w) )
+ if ( ::tqt_cast<TQPopupMenu*>(w) || ::tqt_cast<TQCheckBox*>(w) || ::tqt_cast<TQRadioButton*>(w) || ::tqt_cast<TQStatusBar*>(w) )
w->unsetPalette();
}
@@ -644,21 +644,21 @@ void KThemeStyle::unPolish( const TQStyleControlElementData &ceData, ControlElem
w->setBackgroundMode( TQWidget::PaletteButton );
- //For toolbar internal separators, return to button, too (can't use tqqt_cast here since don't have access to the class)
+ //For toolbar internal separators, return to button, too (can't use tqt_cast here since don't have access to the class)
else if ( w->inherits( "TDEToolBarSeparator" ) || w->inherits( "QToolBarSeparator" ) )
w->setBackgroundMode( TQWidget::PaletteButton );